==> dar-2.5.5.txz: usr/local/include/dar/libdar_config.h <==
#define DAR_LIBDAR_VERSION "2.5.5"
#define DAR_ENABLE_NLS 1
#define LIBDAR_HAS_ARPA_INET_H 1
#define LIBDAR_HAS_BZLIB_H 1
#define LIBDAR_HAS_CTIME_R 1
#define LIBDAR_HAS_CTYPE_H 1
#define LIBDAR_HAS_DCGETTEXT 1
#define LIBDAR_HAS_DECL_SYS_SIGLIST 1
#define LIBDAR_HAS_DIRENT_H 1
#define LIBDAR_HAS_DLFCN_H 1
#define LIBDAR_HAS_ERRNO_H 1
#define LIBDAR_HAS_FCNTL_H 1
#define LIBDAR_HAS_FDOPENDIR 1
#define LIBDAR_HAS_FNMATCH 1
#define LIBDAR_HAS_FNMATCH_H 1
#define LIBDAR_HAS_FORK 1
#define LIBDAR_HAS_GETGRNAM_R 1
#define LIBDAR_HAS_GETOPT_H 1
#define LIBDAR_HAS_GETOPT_IN_UNISTD_H 1
#define LIBDAR_HAS_GETOPT_LONG 1
#define LIBDAR_HAS_GETPWNAM_R 1
#define LIBDAR_HAS_GETTEXT 1
#define LIBDAR_HAS_GRP_H 1
#define LIBDAR_HAS_INTTYPES_H 1
#define LIBDAR_HAS_LCHOWN 1
#define LIBDAR_HAS_LIBBZ2 1
#define LIBDAR_HAS_LIBINTL_H 1
#define LIBDAR_HAS_LIBLZMA 1
#define LIBDAR_HAS_LIBLZO2 1
#define LIBDAR_HAS_LIBPTHREAD 1
#define LIBDAR_HAS_LIBZ 1
#define LIBDAR_HAS_LIMITS_H 1
#define LIBDAR_HAS_LOCALTIME_R 1
#define LIBDAR_HAS_LUTIMES 1
#define LIBDAR_HAS_LZMA_H 1
#define LIBDAR_HAS_LZO_LZO1X_H 1
#define LIBDAR_HAS_MALLOC 1
#define LIBDAR_HAS_MEMORY_H 1
#define LIBDAR_HAS_MKDIR 1
#define LIBDAR_HAS_NETINET_IN_H 1
#define LIBDAR_HAS_OPTRESET 1
#define LIBDAR_HAS_POSIX_FADVISE 1
#define LIBDAR_HAS_PTHREAD_H 1
#define LIBDAR_HAS_PWD_H 1
#define LIBDAR_HAS_READDIR_R 1
#define LIBDAR_HAS_REGCOMP 1
#define LIBDAR_HAS_REGEX_H 1
#define LIBDAR_HAS_RMDIR 1
#define LIBDAR_HAS_SIGNAL_H 1
#define LIBDAR_HAS_STDDEF_H 1
#define LIBDAR_HAS_STDINT_H 1
#define LIBDAR_HAS_STDIO_H 1
#define LIBDAR_HAS_STDLIB_H 1
#define LIBDAR_HAS_STRERROR_R 1
#define LIBDAR_HAS_STRINGS_H 1
#define LIBDAR_HAS_STRING_H 1
#define LIBDAR_HAS_STRUCT_STAT_ST_RDEV 1
#define LIBDAR_HAS_SYS_CAPABILITY_H 1
#define LIBDAR_HAS_SYS_IOCTL_H 1
#define LIBDAR_HAS_SYS_SOCKET_H 1
#define LIBDAR_HAS_SYS_STAT_H 1
#define LIBDAR_HAS_SYS_TIME_H 1
#define LIBDAR_HAS_SYS_TYPES_H 1
#define LIBDAR_HAS_SYS_UN_H 1
#define LIBDAR_HAS_SYS_UTSNAME_H 1
#define LIBDAR_HAS_SYS_WAIT_H 1
#define LIBDAR_HAS_TERMIOS_H 1
#define LIBDAR_HAS_TIME_H 1
#define LIBDAR_HAS_UNISTD_H 1
#define LIBDAR_HAS_UTIME 1
#define LIBDAR_HAS_UTIME_H 1
#define LIBDAR_HAS_UTIME_NULL 1
#define LIBDAR_HAS_VFORK 1
#define LIBDAR_HAS_WCHAR_H 1
#define LIBDAR_HAS_WCTYPE_H 1
#define LIBDAR_HAS_WORKING_FORK 1
#define LIBDAR_HAS_WORKING_VFORK 1
#define LIBDAR_HAS_ZLIB_H 1
#define LIBBZ2_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_BIRTHTIME 1
#define LIBDAR_FAST_DIR 1
#define LIBDAR_MICROSECOND_READ_ACCURACY 1
#define LIBDAR_MICROSECOND_WRITE_ACCURACY 1
#define LIBLZMA_AVAILABLE_FOR_LIBDAR 1
#define LIBLZO2_AVAILABLE_FOR_LIBDAR 1
#define LIBZ_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define LIBDAR_MUTEX_WORKS 1
#define DAR_PACKAGE "dar"
#define DAR_PACKAGE_BUGREPORT "http://sourceforge.net/tracker/?group_id=65612&atid=511612"
#define DAR_PACKAGE_NAME "DAR"
#define DAR_PACKAGE_STRING "DAR 2.5.5"
#define DAR_PACKAGE_TARNAME "dar"
#define DAR_PACKAGE_URL ""
#define DAR_PACKAGE_LIBDAR_VERSION "2.5.5"
#define LIBDAR_SIZEOF_OFF_T 8
#define LIBDAR_SIZEOF_SIZE_T 8
#define LIBDAR_SIZEOF_TIME_T 8
#define LIBDAR_STDC_HEADERS 1
#define LIBDAR_VERSION "2.5.5"

==> dar-2.5.14_3.txz: usr/local/include/dar/libdar_config.h <==
#define BACKTRACE_AVAILABLE_FOR_LIBDAR 1
#define DAR_LIBDAR_VERSION "2.5.14-bis"
#define DAR_ENABLE_NLS 1
#define LIBDAR_HAS_ARPA_INET_H 1
#define LIBDAR_HAS_BZLIB_H 1
#define LIBDAR_HAS_CTIME_R 1
#define LIBDAR_HAS_CTYPE_H 1
#define LIBDAR_HAS_DCGETTEXT 1
#define LIBDAR_HAS_DECL_SYS_SIGLIST 1
#define LIBDAR_HAS_DIRENT_H 1
#define LIBDAR_HAS_DLFCN_H 1
#define LIBDAR_HAS_ERRNO_H 1
#define LIBDAR_HAS_EXECINFO_H 1
#define LIBDAR_HAS_FCNTL_H 1
#define LIBDAR_HAS_FDOPENDIR 1
#define LIBDAR_HAS_FNMATCH 1
#define LIBDAR_HAS_FNMATCH_H 1
#define LIBDAR_HAS_FORK 1
#define LIBDAR_HAS_GETGRNAM_R 1
#define LIBDAR_HAS_GETOPT_H 1
#define LIBDAR_HAS_GETOPT_IN_UNISTD_H 1
#define LIBDAR_HAS_GETOPT_LONG 1
#define LIBDAR_HAS_GETPWNAM_R 1
#define LIBDAR_HAS_GETTEXT 1
#define LIBDAR_HAS_GRP_H 1
#define LIBDAR_HAS_INTTYPES_H 1
#define LIBDAR_HAS_LCHOWN 1
#define LIBDAR_HAS_LIBBZ2 1
#define LIBDAR_HAS_LIBDL 1
#define LIBDAR_HAS_LIBEXECINFO 1
#define LIBDAR_HAS_LIBINTL_H 1
#define LIBDAR_HAS_LIBLZMA 1
#define LIBDAR_HAS_LIBLZO2 1
#define LIBDAR_HAS_LIBPTHREAD 1
#define LIBDAR_HAS_LIBZ 1
#define LIBDAR_HAS_LIMITS_H 1
#define LIBDAR_HAS_LOCALTIME_R 1
#define LIBDAR_HAS_LUTIMES 1
#define LIBDAR_HAS_LZMA_H 1
#define LIBDAR_HAS_LZO_LZO1X_H 1
#define LIBDAR_HAS_MALLOC 1
#define LIBDAR_HAS_MEMORY_H 1
#define LIBDAR_HAS_MKDIR 1
#define LIBDAR_HAS_NETINET_IN_H 1
#define LIBDAR_HAS_OPTRESET 1
#define LIBDAR_HAS_POSIX_FADVISE 1
#define LIBDAR_HAS_PTHREAD_H 1
#define LIBDAR_HAS_PWD_H 1
#define LIBDAR_HAS_READDIR_R 1
#define LIBDAR_HAS_REGCOMP 1
#define LIBDAR_HAS_REGEX_H 1
#define LIBDAR_HAS_RMDIR 1
#define LIBDAR_HAS_SIGNAL_H 1
#define LIBDAR_HAS_STDDEF_H 1
#define LIBDAR_HAS_STDINT_H 1
#define LIBDAR_HAS_STDIO_H 1
#define LIBDAR_HAS_STDLIB_H 1
#define LIBDAR_HAS_STRERROR_R 1
#define LIBDAR_HAS_STRINGS_H 1
#define LIBDAR_HAS_STRING_H 1
#define LIBDAR_HAS_STRUCT_STAT_ST_RDEV 1
#define LIBDAR_HAS_SYS_IOCTL_H 1
#define LIBDAR_HAS_SYS_SOCKET_H 1
#define LIBDAR_HAS_SYS_STAT_H 1
#define LIBDAR_HAS_SYS_TIME_H 1
#define LIBDAR_HAS_SYS_TYPES_H 1
#define LIBDAR_HAS_SYS_UN_H 1
#define LIBDAR_HAS_SYS_UTSNAME_H 1
#define LIBDAR_HAS_SYS_WAIT_H 1
#define LIBDAR_HAS_TERMIOS_H 1
#define LIBDAR_HAS_TIME_H 1
#define LIBDAR_HAS_UNISTD_H 1
#define LIBDAR_HAS_UTIME 1
#define LIBDAR_HAS_UTIME_H 1
#define LIBDAR_HAS_UTIME_NULL 1
#define LIBDAR_HAS_VFORK 1
#define LIBDAR_HAS_WCHAR_H 1
#define LIBDAR_HAS_WCTYPE_H 1
#define LIBDAR_HAS_WORKING_FORK 1
#define LIBDAR_HAS_WORKING_VFORK 1
#define LIBDAR_HAS_ZLIB_H 1
#define LIBBZ2_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_FAST_DIR 1
#define LIBDAR_MICROSECOND_READ_ACCURACY 1
#define LIBDAR_MICROSECOND_WRITE_ACCURACY 1
#define LIBLZMA_AVAILABLE_FOR_LIBDAR 1
#define LIBLZO2_AVAILABLE_FOR_LIBDAR 1
#define LIBZ_AVAILABLE_FOR_LIBDAR 1
#define LIBDAR_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
#define LIBDAR_MUTEX_WORKS 1
#define DAR_PACKAGE "dar"
#define DAR_PACKAGE_BUGREPORT "http://sourceforge.net/tracker/?group_id=65612&atid=511612"
#define DAR_PACKAGE_NAME "DAR"
#define DAR_PACKAGE_STRING "DAR 2.5.14-bis"
#define DAR_PACKAGE_TARNAME "dar"
#define DAR_PACKAGE_URL ""
#define DAR_PACKAGE_LIBDAR_VERSION "2.5.14-bis"
#define LIBDAR_SIZEOF_OFF_T 8
#define LIBDAR_SIZEOF_SIZE_T 8
#define LIBDAR_SIZEOF_TIME_T 8
#define LIBDAR_STDC_HEADERS 1
#define LIBDAR_VERSION "2.5.14-bis"
